'use strict';

exports.__esModule = true;
exports['default'] = createStore;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _utilsIsPlainObject = require('./utils/isPlainObject');

var _utilsIsPlainObject2 = _interopRequireDefault(_utilsIsPlainObject);

function createStore(reducer, initState) {
  if (typeof reducer !== 'function') {
    throw new Error('Expected the reducer to be a function.');
  }

  var initAction = { type: '@@redux-core/INIT_' + new Date().getTime() };
  var currentReducer = reducer;
  var state = currentReducer(initState, initAction);

  function dispatch(action) {
    if (!_utilsIsPlainObject2['default'](action)) {
      throw new Error('Action must be a plain object.');
    }

    state = currentReducer(state, action);
    return state;
  }

  function replaceReducer(newReducer) {
    currentReducer = newReducer;
    dispatch(initAction);
  }

  return {
    getState: function getState() {
      return state;
    },
    dispatch: dispatch,
    getReducer: function getReducer() {
      return currentReducer;
    },
    replaceReducer: replaceReducer
  };
}

module.exports = exports['default'];